---
title: The rules of hooks in Solara
description: Learn the rules that govern the usage of hooks in your Solara application.
----
# Rules of hooks

For now, we refer to the [ReactJS documentation](https://reactjs.org/docs/hooks-rules.html).
